/*
 * Segment 8 Parametrierung und Konfiguration, SWE 8.2 Parametrierung - Bibliothek
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.puk.param.lib.daten;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

/**
 * die Klasse repräsentiert ein Attributfeld.
 *
 * @author BitCtrl Systems GmbH, Peuker
 * @version $Id: Array.java 62370 2016-06-29 13:45:13Z peuker $
 */
class Array extends AbstractAttribut<Collection<Attribut<? extends Object>>> {

	/**
	 * die Versions-ID für die Serialisierung des Objekts.
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * die Liste der Attribute, die das Feld enthält.
	 */
	private final List<Attribut<? extends Object>> eintraege = new ArrayList<>();

	/**
	 * Der Konstruktor erzeugt ein Feld mit dem angegebenen Namen.
	 *
	 * @param name
	 *            der Name
	 */
	Array(final String name) {
		super(name);
	}

	/**
	 * fügt einen Eintrag am Ende des Feldes hinzu.
	 *
	 * @param wert
	 *            der neue Eintrag
	 */
	void add(final Attribut<? extends Object> wert) {
		eintraege.add(wert);
	}

	/**
	 * löscht alle Einträge des Feldes.
	 */
	void clear() {
		eintraege.clear();
	}

	/**
	 * {@inheritDoc}.<br>
	 * Die Funktion liefert die Liste der Einträge innerhalb des Attributfelds.
	 *
	 * @see de.bsvrz.puk.param.lib.daten.Attribut#get()
	 */
	@Override
	public Collection<Attribut<? extends Object>> get() {
		return eintraege;
	}

	/**
	 * liefert das Attribut, das an der mit dem Index definierten Position
	 * innerhalb des Feldes abgelegt ist.
	 *
	 * @param idx
	 *            der Index
	 * @return das Attribut
	 */
	Attribut<?> get(final int idx) {
		return eintraege.get(idx);
	}

	/**
	 * {@inheritDoc}.<br>
	 * Die Funktion entfernt alle innerhalb des Feld abgelegten Einträge und
	 * fügt die Elemente der übergebenen Menge in das Feld ein.
	 *
	 * @see de.bsvrz.puk.param.lib.daten.Attribut#set(java.lang.Object)
	 */
	@Override
	public void set(final Collection<Attribut<? extends Object>> wert) {
		eintraege.clear();
		eintraege.addAll(wert);
	}

	/**
	 * setzt den Wertes des Attributs, das sich innerhalb des Feldes an der
	 * gegebenen Position befindet auf den übergebenen Wert.
	 *
	 * @param idx
	 *            der Index innerhalb des Feldes, an dem das gewünschte Attribut
	 *            zu finden ist
	 * @param wert
	 *            der Wert, der dem Attribut zugewiesen werden soll
	 */
	void set(final int idx, final Attribut<? extends Object> wert) {
		eintraege.set(idx, wert);
	}

	/**
	 * liefert die Größe des Feldes.
	 *
	 * @return die Größe
	 */
	int size() {
		return eintraege.size();
	}
}
