/*
 * Segment 8 Parametrierung und Konfiguration, SWE 8.2 Parametrierung - Bibliothek
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.puk.param.lib.daten;

/**
 * Repräsentiert ein Objektreferenz-Attribut. Der Attributtyp ist hier
 * {@link java.lang.Long}.
 *
 * @author BitCtrl Systems GmbH, Schumann, Peuker
 * @version $Id: ObjektReferenz.java 62370 2016-06-29 13:45:13Z peuker $
 */
class ObjektReferenz extends Ganzzahl {

	/**
	 * Alle Objekte vom Typ <code>Attributliste</code> mit der gleichen UID
	 * können paarweise serialisiert und deserialisiert werden. Objekte mit
	 * unterschiedlicher UID sind inkompatibel.
	 */
	private static final long serialVersionUID = 1L;

	/** die PID bei Referenztyp Assoziation. */
	private String pid;

	/**
	 * konstruiert ein Attribut ohne Wert.
	 *
	 * @param name
	 *            der Name des Attributs
	 */
	ObjektReferenz(final String name) {
		super(name);
	}

	/**
	 * liefert die PID der Referenze bei Assoziationen.
	 *
	 * @return die PID oder null
	 */
	public String getPid() {
		return pid;
	}

	/**
	 * setzt die PID des referenzierten Objekts bei Assoziationen.
	 *
	 * @param pid
	 *            die PID
	 */
	public void setPid(final String pid) {
		this.pid = pid;
	}
}
